This file is part of MXE. See LICENSE.md for licensing information.

Contains ad hoc patches for cross building.

From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Boris Nagaev <bnagaev@gmail.com>
Date: Sat, 1 Apr 2017 15:17:43 +0200
Subject: [PATCH 1/5] Wt fixes


diff --git a/cmake/WtFindGm.txt b/cmake/WtFindGm.txt
index 1111111..2222222 100644
--- a/cmake/WtFindGm.txt
+++ b/cmake/WtFindGm.txt
@@ -59,6 +59,12 @@ IF(WIN32)
   ELSE(GM_LIB AND GMPP_LIB AND GM_LIB_DEBUG AND GMPP_LIB_DEBUG AND GM_INCLUDE_DIR)
     SET(GM_FOUND FALSE)
   ENDIF(GM_LIB AND GMPP_LIB AND GM_LIB_DEBUG AND GMPP_LIB_DEBUG AND GM_INCLUDE_DIR)
+
+  IF(GM_INCLUDE_DIR AND GM_LIBS)
+    SET(GM_FOUND TRUE)
+    SET(GM_INCLUDE_DIRS ${GM_INCLUDE_DIR})
+    SET(GM_LIBRARIES optimized ${GM_LIBS})
+  ENDIF(GM_INCLUDE_DIR AND GM_LIBS)
 ELSE(WIN32)
   FIND_LIBRARY(GM_LIB
     NAMES
diff --git a/cmake/WtFindPangoFt2.txt b/cmake/WtFindPangoFt2.txt
index 1111111..2222222 100644
--- a/cmake/WtFindPangoFt2.txt
+++ b/cmake/WtFindPangoFt2.txt
@@ -47,13 +47,17 @@ SET(PANGO_FT2_INCLUDE_DIRS
     ${GLIB2_INCLUDE_DIR}
     ${GLIB2_CONFIG_INCLUDE_DIR})
 
-SET(PANGO_FT2_LIBRARIES
-    ${PANGO_FT2_LIBRARY}
-    ${PANGO_LIBRARY}
-    ${GOBJECT2_LIBRARY}
-    ${GLIB2_LIBRARY}
-    ${FONTCONFIG_LIBRARY}
-    )
+IF(PANGO_FT2_LIBS)
+    SET(PANGO_FT2_LIBRARIES optimized ${PANGO_FT2_LIBS})
+ELSE(PANGO_FT2_LIBS)
+    SET(PANGO_FT2_LIBRARIES
+        ${PANGO_FT2_LIBRARY}
+        ${PANGO_LIBRARY}
+        ${GOBJECT2_LIBRARY}
+        ${GLIB2_LIBRARY}
+        ${FONTCONFIG_LIBRARY}
+        )
+ENDIF(PANGO_FT2_LIBS)
 
 IF (PANGO_INCLUDE_DIR
     AND FT2_INCLUDE_DIR

From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Mon, 17 Sep 2018 23:31:42 +0200
Subject: [PATCH 2/5] fix missing gmtime_r definition


diff --git a/src/http/Reply.C b/src/http/Reply.C
index 1111111..2222222 100644
--- a/src/http/Reply.C
+++ b/src/http/Reply.C
@@ -13,6 +13,7 @@
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 //
 
+#include <unistd.h>
 #include "Configuration.h"
 #include "Connection.h"
 #include "Reply.h"

From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Sat, 6 Jul 2019 17:25:06 +0200
Subject: [PATCH 3/5] fix build on case senstive filesystem


diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 1111111..2222222 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -574,7 +574,7 @@ IF(HAVE_SSL)
   TARGET_LINK_LIBRARIES(wt PRIVATE ${OPENSSL_LIBRARIES})
   INCLUDE_DIRECTORIES(${OPENSSL_INCLUDE_DIR})
   IF(WIN32)
-    TARGET_LINK_LIBRARIES(wt PRIVATE Crypt32.lib)
+    TARGET_LINK_LIBRARIES(wt PRIVATE crypt32.lib)
   ENDIF(WIN32)
 ELSE(HAVE_SSL)
   MESSAGE("** Disabling crypto support (Auth::SHA1HashFunction, HTTPS support): requires OpenSSL.")
diff --git a/src/Wt/Dbo/backend/MySQL.C b/src/Wt/Dbo/backend/MySQL.C
index 1111111..2222222 100644
--- a/src/Wt/Dbo/backend/MySQL.C
+++ b/src/Wt/Dbo/backend/MySQL.C
@@ -9,8 +9,8 @@
 
 #ifdef WT_WIN32
 #define NOMINMAX
- // WinSock2.h warns that it should be included before windows.h
-#include <WinSock2.h>
+ // winsock2.h warns that it should be included before windows.h
+#include <winsock2.h>
 #endif // WT_WIN32
 
 #include "Wt/Dbo/backend/MySQL.h"
diff --git a/src/Wt/Dbo/backend/Postgres.C b/src/Wt/Dbo/backend/Postgres.C
index 1111111..2222222 100644
--- a/src/Wt/Dbo/backend/Postgres.C
+++ b/src/Wt/Dbo/backend/Postgres.C
@@ -9,8 +9,8 @@
 
 #ifdef WT_WIN32
 #define NOMINMAX
-// WinSock2.h warns that it should be included before windows.h
-#include <WinSock2.h>
+// winsock2.h warns that it should be included before windows.h
+#include <winsock2.h>
 #endif // WT_WIN32
 
 #include "Wt/Dbo/backend/Postgres.h"

From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: Brodie Gaslam <brodie.gaslam@yahoo.com>
Date: Mon, 21 Feb 2022 12:50:37 +0000
Subject: [PATCH 4/5] add include for BOOST_FOREACH


diff --git a/src/Wt/Render/CssParser.C b/src/Wt/Render/CssParser.C
index 1111111..2222222 100644
--- a/src/Wt/Render/CssParser.C
+++ b/src/Wt/Render/CssParser.C
@@ -40,6 +40,7 @@ using namespace Wt::Render;
 #include <boost/phoenix.hpp>
 #endif
 #include <boost/spirit/include/classic_file_iterator.hpp>
+#include <boost/foreach.hpp>
 
 #include <map>
 

From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001
From: brodieG <brodieG@users.noreply.github.com>
Date: Mon, 21 Feb 2022 13:39:57 +0000
Subject: [PATCH 5/5] add <limits> explicitly for GCC 11 changes

Header was previously included implicitly via other
headers

diff --git a/src/Wt/Render/WTextRenderer.C b/src/Wt/Render/WTextRenderer.C
index 1111111..2222222 100644
--- a/src/Wt/Render/WTextRenderer.C
+++ b/src/Wt/Render/WTextRenderer.C
@@ -15,6 +15,7 @@
 
 #include <fstream>
 #include <string>
+#include <limits>
 
 namespace {
   const double EPSILON = 1e-4;
